@@ -239,3 +239,13 @@ def 向上取整(数值):
     :return: 2
     """
     return math.ceil(数值)
+
+
+def 取整数(val):
+    """
+    示例:'8852791.5'返回8852791
+
+    :param 字符串:  8852791.5
+    :return: 8852791
+    """
+    return int(float(val))
\ No newline at end of file
