@@ -464,6 +464,10 @@ class 公用方法(wx.Control):
         '调用此方法将立即重新绘制窗口的无效区域及其所有子级的对象（通常仅在控制流返回事件循环时才发生）'
         return self.Update()
 
+    def 重画(self):
+        self.Refresh()
+        self.Update()
+
     @组件_异常检测
     def 遍历下级组件(self):
         '遍历组件下的子级组件,返回在WindowList 列表里'
@@ -652,7 +656,7 @@ class 公用方法(wx.Control):
 
     @property
     def 左边(self):
-        return self.取左边()
+        return int(self.取左边())
 
     @property
     def 宽度(self):
@@ -660,7 +664,7 @@ class 公用方法(wx.Control):
 
     @property
     def 顶边(self):
-        return self.取顶边()
+        return int(self.取顶边())
 
     @高度.setter
     def 高度(self, value):
@@ -692,7 +696,7 @@ class 公用方法(wx.Control):
 
     @禁止.setter
     def 禁止(self, value):
-        self.禁用(value)
+        self.禁用 = value
 
     @property
     def 鼠标指针(self):
@@ -746,10 +750,11 @@ class 公用方法(wx.Control):
         return self.取边框样式()
 
     @边框.setter
+    @组件_异常检测
     def 边框(self, value):
         pass
         # 等待编写
-        return self.置窗口样式(value)
+        return self.SetWindowStyle(value)
 
     @property
     def 标题(self):
@@ -785,12 +790,20 @@ class 公用方法(wx.Control):
 
     @property
     def 文本颜色(self):
-        return self.文本颜色
+        return self.GetForegroundColour()
 
     @文本颜色.setter
     def 文本颜色(self, value):
-        self.置文本颜色(value)
-        self.文本颜色 = value
+        self.SetForegroundColour(value)
+
+
+    @property
+    def 字体(self):
+        return self.GetFont()
+
+    @字体.setter
+    def 字体(self, value):
+        self.SetFont(value)
 
     @property
     def 背景颜色(self):
@@ -800,6 +813,14 @@ class 公用方法(wx.Control):
     def 背景颜色(self, value):
         return self.置背景颜色(value)
 
+    @property
+    def 底色(self):
+        return self.取背景颜色()
+
+    @底色.setter
+    def 底色(self, value):
+        return self.置背景颜色(value)
+
     @property
     def 窗口样式(self):
         return self.取主题样式()
@@ -815,4 +836,21 @@ class 公用方法(wx.Control):
     @禁用.setter
     def 禁用(self, value):
         "True为禁用组件，False为恢复组件使用"
-        return self.Enable(not value)
\ No newline at end of file
+        return self.Enable(not value)
+
+    @property
+    def 提示文本(self):
+        return self.GetToolTipText()
+
+    @提示文本.setter
+    def 提示文本(self, value):
+        return self.置提示文本(value)
+
+    def 置提示文本(self,value):
+        return self.SetToolTip(value)
+
+    def 取提示文本(self):
+        return self.GetToolTipText()
+
+    def 删除提示文本(self):
+        self.UnsetToolTip()
\ No newline at end of file
